Vagas pra mim

This project was born from the will of its collaborators to help people to find jobs more easily. We went through a very difficult pandemic period for everyone in which several people lost their jobs and were unable to find a place in the job market. To change this scenario, we collect and make available vacancies from different companies automatically so that people can compare their resumes with the market positions that are most relevant to them. This includes you. We understand that in this way, we will be able to unite those who need collaborators and those who need to work. This project is completely free and relies on the collaboration of the community to grow and reach more people. If you like this initiative, see here how you can contribute and make the project expand.